#
# spec file for package kf6-kfilemetadata
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.6.0

%define rname kfilemetadata
# Full KF6 version (e.g. 6.6.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without ffmpeg
%bcond_without released
Name:           kf6-kfilemetadata
Version:        6.6.0
Release:        1.1
Summary:        Library for extracting Metadata
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND LGPL-3.0-only
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  libattr-devel
BuildRequires:  libepub-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(exiv2) >= 0.21
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Codecs) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6Config) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
# Not packaged yet
# BuildRequires:  cmake(QMobipocket6)
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
BuildRequires:  pkgconfig(poppler-qt6)
BuildRequires:  pkgconfig(taglib)
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif

%description
KFileMetaData provides plugins for extracting file metadata.

%package -n libKF6FileMetaData3
Summary:        Library for extracting Metadata
Requires:       kf6-kfilemetadata >= %{version}

%description -n libKF6FileMetaData3
A library for extracting file metadata.

%package devel
Summary:        Development package for kfilemetadata
Requires:       libKF6FileMetaData3 = %{version}
Requires:       cmake(Qt6Core) >= %{qt6_version}

%description devel
A library for extracting file metadata. Development files

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang kfilemetadata6 --all-name

%ldconfig_scriptlets -n libKF6FileMetaData3

%files
%{_kf6_debugdir}/kfilemetadata.categories
%{_kf6_debugdir}/kfilemetadata.renamecategories
%{_kf6_plugindir}/kf6/kfilemetadata/

%files -n libKF6FileMetaData3
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6FileMetaData.so.*

%files devel
%doc %{_kf6_qchdir}/KF6FileMetaData.*
%{_kf6_cmakedir}/KF6FileMetaData/
%{_kf6_includedir}/KFileMetaData/
%{_kf6_libdir}/libKF6FileMetaData.so

%files lang -f kfilemetadata6.lang

%changelog
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
  * UserMetadata: fix Win k_setxattr
  * [OfficeExtractor] Do not add word/line count if nothing has been extracted
  * [OfficeExtractor] Only try to extract content if PlainText is requested
  * [OfficeExtractor] Remove duplicate findExecutable calls, fix debug output
  * cmake: Use KDE_INSTALL_FULL_LIBEXECDIR_KF instead of manual path mangling (kde#491462)
  * Add missing initializer for "Empty" PropertyInfo displayName
  * [Taglib] Use non-deprecated constructors for MPEG::File/FLAC::File
  * [Taglib] Replace deprecated length() with lengthInSeconds()
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * [Extractors] Clarify Qt::Gui dependencies
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- No code change since 6.3.0
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Remove explicit maintainer from metainfo
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * API dox: add some minimal info to undocumented classes
  * UserMetadata: return errors when xattr ops fails
  * Value is already default timeout value in QT6 framework
  * [XmlExtractor] Add support for compressed SVGs
  * [XmlExtractorTest] Move Test class declaration to source file
  * [Office2007Extractor] Reuse DublinCoreExtractor, fix namespace handling
  * [DublinCoreExtractor] Add CreationDate (dc::created) support
  * [DublinCoreExtractor] Skip properties from empty elements, cleanup
  * Move date parser helper out of ExtractorPlugin, clean it up
  * [TaglibExtractor] Include vnd.audible.aaxc audio books in supported types
  * [Test] Include vnd.audible.aax audio books in coverage tests
  * [TaglibWriterTest] Move test class declaration to source file, cleanup
  * [TaglibExtractor|Writer] Fix mimetypes
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * [PopplerExtractorTest] Verify multicolumn PDF content (currently broken)
  * [PopplerExtractorTest] Make tests data driven
  * [PopplerExtractorTest] Move class declaration to source file
  * plaintextextractor: autodetect encoding for text
  * [PlainTextExtractor] Add plain text test file to coverage test
  * [IndexerExtractorTest] Make tests data driven
  * Add support for .mod/.s3m/.xm/.it Module Tracker formats meta data (kde#448182)
  * plaintextextractor: Read file via QFile
  * [PropertyInfo,TypeInfo] Move static data into scope of its class
  * [PropertyInfo,TypeInfo] Avoid lookup from id during initilization
  * [PropertyInfo,TypeInfo] Use QStringView for name in hash
  * [TypeInfo] Use a hash table for faster fromName TypeInfo creation
  * Move helper class for case-insensitive QHash lookup to separate file
  * [TypeInfo] Make set of all types introspectable
  * [TypeInfo] Improve performance and cleanup
  * [TypeInfo] Add unit tests and benchmarks
  * [TypeInfo] Extend documentation for KFileMetaData::TypeInfo
  * [PlaintextExtractor] Fix possible truncation of last character
  * [PlaintextExtractor] Verify handling files missing newline delimiters
  * [PlaintextExtractor] Check countint of empty lines
  * [IndexerExtractorTest] Actually verify content extraction is skipped
  * [IndexerExtractorTest] Move class declaration to source file
  * [CMake] Move mentions of KF Archive dependencies over to the extractors
  * [CMake] Remove several leftover references to KF5
  * Fix compilation error for krita extractor when KArchive isn't found
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * ensure Windows tests keep working
  * share loop code
  * fix handling of attribute namespacing
  * don't crash if no tags found
  * Require taglib 1.12
  * Port away from deprecated QDateTime API
  * There's no QVector anymore, QList is the QVector in Qt6
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kfilemetadata
